@@ -71,7 +71,7 @@ export class PlaceEntry extends Gtk.Entry {
         }
 
         if (this.text !== this._placeText)
-            this._setTextWithoutTriggerSearch(this._placeText);
+            this.setTextWithoutTriggeringSearch(this._placeText);
 
         this._place = p;
 
@@ -125,7 +125,7 @@ export class PlaceEntry extends Gtk.Entry {
         this.add_css_class('search');
     }
 
-    _setTextWithoutTriggerSearch(text) {
+    setTextWithoutTriggeringSearch(text) {
         this._setText = text;
         this.text = text;
     }
@@ -435,11 +435,6 @@ export class PlaceEntry extends Gtk.Entry {
         this.text = '';
         this.grab_focus();
     }
-
-    vfunc_size_allocate(width, height, baseline) {
-        super.vfunc_size_allocate(width, height, baseline);
-        this._popover.present();
-    }
 }
 
 GObject.registerClass({
